using System.Collections;
using System.Collections.Generic;
using TMPro;
using UnityEngine;
using UnityEngine.Timeline;
using UnityEngine.UI;

public class UIDialog : MonoBehaviour
{
	public TMP_Text DialogText;
	public TMP_Text NameText;

	[Header("VariantMenu")]
	public UiDialogVariant DialogElement;

	public Button NextButton;

	public string InitDialog = "Dialogs/DialogScriptableObject";

	private IDialogNode _node;

	private void Start()
	{
		NextButton.onClick.AddListener(OnNextButton);

		GetNextDialog(InitDialog);
	}

	private void OnNextButton()
	{
		_node.GetNextDialog(ShowText, ShowVariantDialog, GetNextDialog);
	}

	public void GetNextDialog(string nextDialog)
	{
		if (string.IsNullOrWhiteSpace(nextDialog))
		{
			gameObject.SetActive(false);
			return;
		}

		var dialog = Resources.Load(nextDialog);
		if (dialog is BaseDialogNodeScriptableObject nodeContainer)
		{
			_node = nodeContainer.GetNode();
			OnNextButton();
		}
	}

	private void ShowText(TextNode textToShow)
	{
		DialogText.text = textToShow.Text;
		NameText.text = textToShow.CharacterName;
		NameText.color = textToShow.CharacterNameColor;

		if (!string.IsNullOrEmpty(textToShow.MySignalData))
		{
			//DialogSignal.Send(textToShow.MySignalData);
		}

		DialogElement.gameObject.SetActive(false);
	}

	private void ShowVariantDialog(SelectVariantDialogNode variantToShow)
	{
		ShowText(variantToShow.BottomText);

		DialogElement.gameObject.SetActive(true);

		DialogElement.ShowOptions(variantToShow.Options, GetNextDialog);
	}
}
